==> tuia-advert-center-api-2.4.3-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/data/PromoteUrlDayDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.data;

import java.io.Serializable;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName: PromoteUrlDayDto <br/>
 * Function: 广告主-广告-日期-落地页实时数据. <br/>
 * date: 2018年4月19日 下午5:41:09 <br/>
 *
 * @author chencheng
 * @version
 * @since JDK 1.8
 */
public class PromoteUrlDayDto implements Serializable {

    private static final long serialVersionUID = -6372981701571548183L;

    /** 广告ID. */
    private Long   accountId;

    /** 广告ID. */
    private Long   advertId;

    /** 落地页链接md5加密值. */
    private String urlMd5;

    /** 曝光量. */
    private Long   exposureCount;

    /** 点击数. */
    private Long   clickCount;

    /** 总花费. */
    private Long   consumeTotal;

    /** 访问pv. */
    private Long   visitPv;

    /** 转化pv. */
    private Long   effectPv;

    /** 查询时间段. */
    private String curDate;

    /**
     * accountId.
     *
     * @return the accountId
     * @since JDK 1.8
     */
    public Long getAccountId() {
        return accountId;
    }

    /**
     * accountId.
     *
     * @param accountId the accountId to set
     * @since JDK 1.8
     */
    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    /**
     * advertId.
     *
     * @return the advertId
     * @since JDK 1.8
     */
    public Long getAdvertId() {
        return advertId;
    }

    /**
     * advertId.
     *
     * @param advertId the advertId to set
     * @since JDK 1.8
     */
    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    /**
     * urlMd5.
     *
     * @return the urlMd5
     * @since JDK 1.8
     */
    public String getUrlMd5() {
        return urlMd5;
    }

    /**
     * urlMd5.
     *
     * @param urlMd5 the urlMd5 to set
     * @since JDK 1.8
     */
    public void setUrlMd5(String urlMd5) {
        this.urlMd5 = urlMd5;
    }

    /**
     * exposureCount.
     *
     * @return the exposureCount
     * @since JDK 1.8
     */
    public Long getExposureCount() {
        return exposureCount;
    }

    /**
     * exposureCount.
     *
     * @param exposureCount the exposureCount to set
     * @since JDK 1.8
     */
    public void setExposureCount(Long exposureCount) {
        this.exposureCount = exposureCount;
    }

    /**
     * clickCount.
     *
     * @return the clickCount
     * @since JDK 1.8
     */
    public Long getClickCount() {
        return clickCount;
    }

    /**
     * clickCount.
     *
     * @param clickCount the clickCount to set
     * @since JDK 1.8
     */
    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }

    /**
     * consumeTotal.
     *
     * @return the consumeTotal
     * @since JDK 1.8
     */
    public Long getConsumeTotal() {
        return consumeTotal;
    }

    /**
     * consumeTotal.
     *
     * @param consumeTotal the consumeTotal to set
     * @since JDK 1.8
     */
    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }

    /**
     * visitPv.
     *
     * @return the visitPv
     * @since JDK 1.8
     */
    public Long getVisitPv() {
        return visitPv;
    }

    /**
     * visitPv.
     *
     * @param visitPv the visitPv to set
     * @since JDK 1.8
     */
    public void setVisitPv(Long visitPv) {
        this.visitPv = visitPv;
    }

    /**
     * effectPv.
     *
     * @return the effectPv
     * @since JDK 1.8
     */
    public Long getEffectPv() {
        return effectPv;
    }

    /**
     * effectPv.
     *
     * @param effectPv the effectPv to set
     * @since JDK 1.8
     */
    public void setEffectPv(Long effectPv) {
        this.effectPv = effectPv;
    }

    /**
     * curDate.
     *
     * @return the curDate
     * @since JDK 1.8
     */
    public String getCurDate() {
        return curDate;
    }

    /**
     * curDate.
     *
     * @param curDate the curDate to set
     * @since JDK 1.8
     */
    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    /**
     * To string.
     *
     * @return the string
     */
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> tuia-advert-center-api-2.6.17-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/data/PromoteUrlDayDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.data;

import java.io.Serializable;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName: PromoteUrlDayDto <br/>
 * Function: 广告主-广告-日期-落地页实时数据. <br/>
 * date: 2018年4月19日 下午5:41:09 <br/>
 *
 * @author chencheng
 * @version
 * @since JDK 1.8
 */
public class PromoteUrlDayDto implements Serializable {

    private static final long serialVersionUID = -6372981701571548183L;

    /** 广告ID. */
    private Long   accountId;

    /** 广告ID. */
    private Long   advertId;

    /** 落地页链接md5加密值. */
    private String urlMd5;

    /** 曝光量. */
    private Long   exposureCount;

    /** 点击数. */
    private Long   clickCount;

    /** 总花费. */
    private Long   consumeTotal;

    /** 访问pv. */
    private Long   visitPv;

    /** 转化pv. */
    private Long   effectPv;

    /** 查询时间段. */
    private String curDate;

    /**
     * 注册pv
     */
    private Long registPv;

    public Long getRegistPv() {
        return registPv;
    }

    public void setRegistPv(Long registPv) {
        this.registPv = registPv;
    }

    /**
     * accountId.
     *
     * @return the accountId
     * @since JDK 1.8
     */
    public Long getAccountId() {
        return accountId;
    }

    /**
     * accountId.
     *
     * @param accountId the accountId to set
     * @since JDK 1.8
     */
    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    /**
     * advertId.
     *
     * @return the advertId
     * @since JDK 1.8
     */
    public Long getAdvertId() {
        return advertId;
    }

    /**
     * advertId.
     *
     * @param advertId the advertId to set
     * @since JDK 1.8
     */
    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    /**
     * urlMd5.
     *
     * @return the urlMd5
     * @since JDK 1.8
     */
    public String getUrlMd5() {
        return urlMd5;
    }

    /**
     * urlMd5.
     *
     * @param urlMd5 the urlMd5 to set
     * @since JDK 1.8
     */
    public void setUrlMd5(String urlMd5) {
        this.urlMd5 = urlMd5;
    }

    /**
     * exposureCount.
     *
     * @return the exposureCount
     * @since JDK 1.8
     */
    public Long getExposureCount() {
        return exposureCount;
    }

    /**
     * exposureCount.
     *
     * @param exposureCount the exposureCount to set
     * @since JDK 1.8
     */
    public void setExposureCount(Long exposureCount) {
        this.exposureCount = exposureCount;
    }

    /**
     * clickCount.
     *
     * @return the clickCount
     * @since JDK 1.8
     */
    public Long getClickCount() {
        return clickCount;
    }

    /**
     * clickCount.
     *
     * @param clickCount the clickCount to set
     * @since JDK 1.8
     */
    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }

    /**
     * consumeTotal.
     *
     * @return the consumeTotal
     * @since JDK 1.8
     */
    public Long getConsumeTotal() {
        return consumeTotal;
    }

    /**
     * consumeTotal.
     *
     * @param consumeTotal the consumeTotal to set
     * @since JDK 1.8
     */
    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }

    /**
     * visitPv.
     *
     * @return the visitPv
     * @since JDK 1.8
     */
    public Long getVisitPv() {
        return visitPv;
    }

    /**
     * visitPv.
     *
     * @param visitPv the visitPv to set
     * @since JDK 1.8
     */
    public void setVisitPv(Long visitPv) {
        this.visitPv = visitPv;
    }

    /**
     * effectPv.
     *
     * @return the effectPv
     * @since JDK 1.8
     */
    public Long getEffectPv() {
        return effectPv;
    }

    /**
     * effectPv.
     *
     * @param effectPv the effectPv to set
     * @since JDK 1.8
     */
    public void setEffectPv(Long effectPv) {
        this.effectPv = effectPv;
    }

    /**
     * curDate.
     *
     * @return the curDate
     * @since JDK 1.8
     */
    public String getCurDate() {
        return curDate;
    }

    /**
     * curDate.
     *
     * @param curDate the curDate to set
     * @since JDK 1.8
     */
    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    /**
     * To string.
     *
     * @return the string
     */
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
